from maltego_trx.maltego import MaltegoTransform


class DiscoverableTransform:
    @classmethod
    def create_entities(cls, request, response):
        raise NotImplementedError("create_entities static method must be implemented in child class.")

    @classmethod
    def run_transform(cls, request):
        response = MaltegoTransform()
        cls.create_entities(request, response)
        return response.returnOutput()



Alias = "maltego.Alias"
ASNumber = "maltego.AS"
BuiltwithTechnology = "maltego.Builtwith.Technology"
CircularArea = "maltego.CircularArea"
Device = "maltego.Device"
DNS = "maltego.DNSName"
Document = "maltego.Document"
Domain = "maltego.Domain"
Email = "maltego.EmailAddress"
FlickrAffiliation = "maltego.AffiliationFlickr"
GPS = "maltego.GPS"
Hashtag = "maltego.Hashtag"
Image = "maltego.Image"
IPAddress = "maltego.IPv4Address"
Location = "maltego.Location"
MX = "maltego.MXRecord"
MyspaceAffiliation = "maltego.AffiliationMyspace"
Namechk = "maltego.Namechk"
Netblock = "maltego.Netblock"
NS = "maltego.NSRecord"
Person = "maltego.Person"
PhoneNumber = "maltego.PhoneNumber"
Phrase = "maltego.Phrase"
Sentiment = "maltego.Sentiment"
StockSymbol = "maltego.StockSymbol"
Tweet = "maltego.Twit"
TwitterAffiliation = "maltego.AffiliationTwitter"
TwitterList = "maltego.TwitterUserList"
UniqueID = "maltego.UniqueIdentifier"
URL = "maltego.URL"
Website = "maltego.Website"
WebTitle = "maltego.WebTitle"




import re
from six import text_type, binary_type


def name_to_path(name):
    # Convert function name to a URL path
    path = name.replace("_", "-")
    return path.lower()


def make_utf8(val):
    """
    Py2: makes variable a utf-8 encoded Unicode type
    Py3: make variable a utf-8 encoded str type
    :param val: the variable we want unicode encoded
    :return: val {Byte/Unicode}
    """
    return force_encoding(val, 'utf-8')


def make_printable(val):
    """
    Py2: makes variable a ascii encoded Unicode type
    Py3: make variable a ascii encoded str type
    :param val: the variable we want unicode encoded
    :return: val {Byte/Unicode}
    """
    return force_encoding(val, 'ascii')


def force_encoding(val, encoding):
    if type(val) == text_type:
        return val.encode(encoding, 'replace').decode(encoding, 'replace')
    elif type(val) == binary_type:
        return val.decode(encoding, 'replace')
    else:
        return text_type(val).encode(encoding, 'replace').decode(encoding, 'replace')


def remove_invalid_xml_chars(val):
    """
    Remove characters which aren't allowed in XML.
    :param val:
    :return:
    """
    val = make_utf8(val)
    val = re.sub(u'[^\u0020-\uD7FF\u0009\u000A\u000D\uE000-\uFFFD\U00010000-\U0010FFFF]+', '?', val)
    return val


from setuptools import setup
from maltego_trx import VERSION

setup(name='maltego-trx',
      version=VERSION,
      description='Python library used to develop Maltego transforms',
      url='https://github.com/paterva/maltego-trx/',
      author='Maltego Staff',
      author_email='support@maltego.com',
      license='MIT',
      install_requires=[
       'flask>=1',
       'six>=1'
      ],
      packages=[
          'maltego_trx',
          'maltego_trx/template_dir',
          'maltego_trx/template_dir/transforms'
      ],
      entry_points={'console_scripts': [
          'maltego-trx = maltego_trx.commands:execute_from_command_line',
      ]},
      zip_safe=False
      )



import socket
from maltego_trx.maltego import UIM_TYPES
from maltego_trx.entities import IPAddress

from maltego_trx.transform import DiscoverableTransform


class DNSToIP(DiscoverableTransform):
    """
    Receive DNS name from the client, and resolve to IP address.
    """

    @classmethod
    def create_entities(cls, request, response):
        dns_name = request.Value

        try:
            ip_address = socket.gethostbyname(dns_name)
            response.addEntity(IPAddress, ip_address)
        except socket.error as e:
            response.addUIMessage("Error: " + str(e), UIM_TYPES["partial"])

        # Write the slider value as a UI message - just for fun
        response.addUIMessage("Slider value is at: " + str(request.Slider))



from maltego_trx.entities import Phrase

from maltego_trx.transform import DiscoverableTransform


class GreetPerson(DiscoverableTransform):
    """
    Returns a phrase greeting a person on the graph.
    """

    @classmethod
    def create_entities(cls, request, response):
        person_name = request.Value

        response.addEntity(Phrase, "Hi %s, nice to meet you!" % person_name)
